#!/usr/bin/python
#-*- coding: UTF-8 -*-

#***********************************************
# R2spec 
#
# R2spec is made to help to the creation of R specfile
# It works from a source file (*.tar.gz) or a url (http://...*.tar.gz)
#
#
# Made the 13th February 2008
# by Pierre-Yves chibon
#
#
# Distributed under License GPLv3 or later
# You can find a copy of this license on the website
# http://www.gnu.org/licenses/gpl.html
#
# This software has been based on the guidelines for R packaging
# http://fedoraproject.org/wiki/Packaging/R
#
#***********************************************

from Package import *
from optparse import OptionParser
import getopt, sys, re


USAGE ="""
This program is designed to create specfile from a source file or a url.
Usage:  R2spec -u <url> 
        R2spec -s <source>
        R2spec -s folder/folder/<source>

You can also use the following options to add the correct Source0 in the spec file:
  --bioc                For Bioconductor libraries
  --cran                For libraries coming from the CRAN repository

The source can be in the same directory or in a subdirectory.

The information about the packager:
- Fill /etc/R2spec.conf 
- Copy and fill /etc/R2spec to ~/.R2spec.conf
- Use the option -n/--name and -e/--email to set the corresponding values
"""

 
#################################################
### argument
# retrieve the arguments given and show the help when needed
def getArgument():
    ''' Handle the parameters'''
    parser = OptionParser(version="%prog 2.5.2")
    parser.add_option("-u", "--url", dest="url",
                  help="Url of the R library")
    parser.add_option("-s", "--source", dest="source",
                  help="The source file (tarball) of the R library")
    parser.add_option("--bioc", dest="bioc", default=False, action="store_true",
                  help="For Bioconductor libraries, will add the correct Source0 in the spec file")
    parser.add_option("--cran", dest="cran", default=False, action="store_true",
                  help="For libraries coming from the CRAN repository, will add the correct Source0 in the spec file")
    parser.add_option("-c", "--copyFile", dest="copyFile", default=False, action="store_true",
                  help="Copy directly the file to the SOURCES folder without asking")
    parser.add_option("-n", "--name", dest="name",
                  help="Name of the packager that will be used in the spec file")
    parser.add_option("-e", "--email", dest="email",
                  help="Email of the packager that will be used in the spec file")
    parser.add_option("-f", "--force", dest="force", default=False, action="store_true",
                  help="Create the spec file even if a file of the same name exists allready in the working directory")
    (options, args) = parser.parse_args()

    return (options.source, options.url, options.bioc, options.cran, options.copyFile, options.name, \
    options.email, options.force)
################################################


#################################################
### main
# Do the job :)

# Retrieve the given arguments
(source, url, bioc, cran, copyFile, name, email, force) = getArgument()

# Return the usage message if no arguments are given
if(url == None and source == None):
    sys.exit(USAGE)

# Return an error message if there is 2 arguments given
if (url != None and source != None):
    sys.exit("\n***  Please give only one argument  ***\n")

# Fails if a library comes from both bioconductor and cran
if (cran == True and bioc == True):
    sys.exit("\n***  The library can not be --bioc and --cran at the same time  ***\n")

# Check wether the url or the source exist and if so check wether they are http:// and tar.gz
if(url != None):
    # Check wether the url start with http://
    if not url.startswith('http://'):
        sys.exit("\nYour URL does not start with 'http://' => %s \n" % url)

    # Check wether the url refers to a .tar.gz
    if not url.startswith('http://') and not url.endswith('.tar.gz'):
        sys.exit("Your URL does not link to a tarball file %s \n" % url)

if(source != None):
    if not source.endswith('.tar.gz') and not source.endswith('.zip'):    
        sys.exit("Your source is not a tarball (*.tar.gz) or a zip file (*.zip) %s \n" % source )
    if not os.path.exists(source):
        sys.exit("Your source does not exist")

package = Package()
package.setSource(url, source)
package.download()
package.setPackager(bioc, name, email)
print "\n","*"*50
print "* Name of the packager =", package.packager.name
print "* Mail of the packager =", package.packager.email
if bioc: print "* Release of Bioconductor =", package.packager.bioc
package.setName()
print "* Name of the library =", package.name
if bioc: package.setBiocUrl()
if cran: package.setCranUrl()
package.openSource()
package.setDescription()
print "* Version of the library =", package.description.version
print "* Summary of the library = ", package.description.summary
print "* Description of the library =\n   ", package.description.description
print "* License of the library =", package.description.license
package.getArch()
if package.arch == 'noarch':
    print "* The package is = Noarch" 
else:
    print "* The package is = Arch ~ x86 or x86_64" 
package.closeSource()
package.setDate()
print "* Date of the spec file =", package.date
print "*"*50,"\n\n Generate the spec file\n"
package.writeSpec(force)
package.moveSource(copyFile)
